# mercury-sync
[![PyPI version](https://img.shields.io/pypi/v/mercury-sync?color=gre)](https://pypi.org/project/mercury-sync/)
[![License](https://img.shields.io/github/license/scorbettUM/mercury-sync)](https://github.com/scorbettUM/mercury-sync/blob/main/LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/scorbettUM/mercury-sync/blob/main/CODE_OF_CONDUCT.md)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mercury-sync)](https://pypi.org/project/mercury-sync/)

Mercury-SyNC (Systems Networking Controller) is a pure-Python, asyncio-based library for authoring distributed systems.
